@@ -456,7 +456,8 @@ impl ReduceAst {
     fn can_remove(&self, e: &Expr) -> bool {
         match e {
             Expr::Invalid(..) => true,
-            Expr::Lit(..) => !self.preserve_lit,
+            Expr::Lit(Lit::Str(..)) => false,
+            Expr::Lit(..) => true,
             Expr::Seq(seq) => seq.exprs.iter().all(|e| self.can_remove(e)),
             _ => false,
         }
@@ -565,9 +566,9 @@ impl VisitMut for ReduceAst {
             }) => {
                 self.ignore_expr(callee);
 
-                let is_define = match &**callee {
+                let is_string_lit_important = match &**callee {
                     Expr::Ident(callee) => {
-                        if &*callee.sym == "define" {
+                        if &*callee.sym == "define" || &*callee.sym == "require" {
                             true
                         } else {
                             false
@@ -590,7 +591,7 @@ impl VisitMut for ReduceAst {
                     let old_preserver_fn = self.preserve_fn;
                     self.preserve_fn = !callee.is_fn_expr() && !callee.is_arrow();
                     let old_preserve_lit = self.preserve_lit;
-                    self.preserve_lit |= is_define;
+                    self.preserve_lit |= is_string_lit_important;
                     e.visit_mut_children_with(self);
 
                     self.preserve_lit = old_preserve_lit;
